GradientSampler

Struct GradientSampler 

pub struct GradientSampler {
    pub points: usize,
    pub margin_left: u32,
    pub margin_right: u32,
    pub margin_top: u32,
    pub margin_bottom: u32,
    pub maps: Vec<(String, BTreeMap<u32, RGBA32>)>,
}
A color interpolator that interpolates between colors in the RGB Color Space.

Fields

points: usize

The number of points to sample from the gradient.

margin_left: u32

The number of pixels to add to the left of the gradient.

margin_right: u32

The number of pixels to add to the right of the gradient.

margin_top: u32

The number of pixels to add to the top of the gradient.

margin_bottom: u32

The number of pixels to add to the bottom of the gradient.

maps: Vec<(String, BTreeMap<u32, RGBA32>)>

The gradient maps.

Implementations

Source

impl GradientSampler

pub fn new(points: usize) -> Self

Arguments
Arguments
  • margin:

returns: GradientSampler

Examples
pub fn with_margin(self, margin: u32) -> Self

Arguments
Arguments
  • margin:

returns: GradientSampler

Examples
pub fn sample(&self, image: &Rgba32FImage) -> BTreeMap<u32, RGBA32>

Arguments
Arguments
  • margin:

returns: GradientSampler

Examples
pub fn sample_file<P>( &mut self, path: P, name: &str, ) -> Result<(), Box<dyn Error>>
where P: AsRef<Path>,

Arguments
Arguments
  • margin:

returns: GradientSampler

Examples
pub fn export_hsv<P>(&self, path: P) -> ImageResult<()>
where P: AsRef<Path>,

Arguments
Arguments
  • margin:

returns: GradientSampler

Examples