pub struct GradientSampler {
pub points: usize,
pub margin_left: u32,
pub margin_right: u32,
pub margin_top: u32,
pub margin_bottom: u32,
pub maps: Vec<(String, BTreeMap<u32, RGBA32>)>,
}Expand description
A color interpolator that interpolates between colors in the RGB Color Space.
Fields
points: usizeThe number of points to sample from the gradient.
margin_left: u32The number of pixels to add to the left of the gradient.
margin_right: u32The number of pixels to add to the right of the gradient.
margin_top: u32The number of pixels to add to the top of the gradient.
margin_bottom: u32The number of pixels to add to the bottom of the gradient.
maps: Vec<(String, BTreeMap<u32, RGBA32>)>The gradient maps.
Implementations
Sourceimpl GradientSampler
impl GradientSampler
Sourcepub fn with_margin(self, margin: u32) -> Self
pub fn with_margin(self, margin: u32) -> Self
Sourcepub fn export_hsv<P>(&self, path: P) -> ImageResult<()>
pub fn export_hsv<P>(&self, path: P) -> ImageResult<()>